Reader

Struct Reader 

pub struct Reader<R: ?Sized> { /* private fields */ }
A reader, which can dynamically provide IO traits.

The following traits may be optionally dynamically provided:

The struct comes with a number of setter methods. The call to these requires proof to the compiler that the bound is met, inserting the vtable from the impl instance. Afterward, the bound is not required by any user. Using the (mutable) getters recombines the vtable with the underlying value.

Note that the value can not be unsized (dyn trait) itself. This may be fixed at a later point to make the reader suitable for use in embedded. In particular, the double indirection of instantiating with R = &mut dyn Read wouldn’t make sense as the setters would not be usable, their bounds can never be met. And combining traits into a large dyn-trait is redundant as it trait-impls become part of the static validity requirement again.

Usage

let mut buffer: &[u8] = b"Hello, world!";
let mut reader = Reader::new(&mut buffer);
assert!(reader.as_buf().is_none());

// But slices are buffered readers, let's tell everyone.
reader.set_buf();
assert!(reader.as_buf().is_some());

// Now use the ReadBuf implementation directly
let buffered = reader.as_buf_mut().unwrap();
buffered.consume(7);
assert_eq!(buffered.fill_buf().unwrap(), b"world!");

Implementations

Source

impl<R: Read> Reader<R>

pub fn new(reader: R) -> Self

Wrap an underlying reader by-value.

Source

impl<R: ?Sized> Reader<R>

pub fn get_ref(&self) -> &R

Provide access to the underlying reader.

pub fn get_mut(&mut self) -> &mut R

Provide mutable access to the underlying reader.

pub fn as_mut(&mut self) -> ReaderMut<'_>

Get a view equivalent to very-fat mutable reference.

This erases the concrete type R which allows consumers that intend to avoid polymorphic code that monomorphizes. The mutable reference has all accessors of a mutable reference except it doesn’t offer access with the underlying reader’s type itself.

pub fn into_boxed<'lt>(self) -> ReaderBox<'lt>
where R: Sized + 'lt,

Get an allocated, type-erased very-fat mutable box.

This erases the concrete type R which allows consumers that intend to avoid polymorphic code that monomorphizes. The mutable reference has all accessors of a mutable reference except it doesn’t offer access with the underlying reader’s type itself.

Source

impl<R> Reader<R>

pub fn set_buf(&mut self)
where R: BufRead,

Set the V-Table for BufRead.

After this call, the methods Self::as_buf and Self::as_buf_mut will return values.

pub fn set_seek(&mut self)
where R: Seek,

Set the V-Table for Seek.

After this call, the methods Self::as_seek and Self::as_seek_mut will return values.

pub fn set_any(&mut self)
where R: Any,

Set the V-Table for Any.

After this call, the methods Self::as_any and Self::as_any_mut will return values.

Source

impl<R> Reader<R>

pub fn set_file_ext(&mut self)
where R: FileExt,

Set the V-Table for FileExt.

After this call, the methods Self::as_file_ext will return a value. (This trait only has methods with a &self receiver).

pub fn set_as_fd(&mut self)
where R: AsFd,

Set the V-Table for AsRawFd.

After this call, the methods Self::as_fd will return a value. (This trait only has methods with a &self receiver).

pub fn set_as_raw_fd(&mut self)
where R: AsRawFd,

Set the V-Table for AsRawFd.

After this call, the methods Self::as_raw_fd will return a value. (This trait only has methods with a &self receiver).

Source

impl<R: ?Sized> Reader<R>

pub fn as_read(&self) -> &(dyn Read + '_)

Get the inner value as a shared dynamic Read reference.

This is not terribly useful but provided for completeness.

pub fn as_read_mut(&mut self) -> &mut (dyn Read + '_)

Get the inner value as a mutable dynamic Read reference.

pub fn into_inner(self) -> R
where R: Sized,

Unwrap the inner value at its original sized type.

Source

impl<R: ?Sized> Reader<R>

pub fn as_buf(&self) -> Option<&dyn BufRead>

Get the inner value as a dynamic BufRead reference.

This returns None unless a previous call to Self::set_buf as executed, by any other caller. The value can be moved after such call arbitrarily.

pub fn as_buf_mut(&mut self) -> Option<&mut dyn BufRead>

Get the inner value as a mutable dynamic BufRead reference.

This returns None unless a previous call to Self::set_buf as executed, by any other caller. The value can be moved after such call arbitrarily.

pub fn as_seek(&self) -> Option<&dyn Seek>

Get the inner value as a dynamic Seek reference.

This returns None unless a previous call to Self::set_seek as executed, by any other caller. The value can be moved after such call arbitrarily.

pub fn as_seek_mut(&mut self) -> Option<&mut dyn Seek>

Get the inner value as a mutable dynamic Seek reference.

This returns None unless a previous call to Self::set_seek as executed, by any other caller. The value can be moved after such call arbitrarily.

pub fn as_any(&self) -> Option<&dyn Any>

Get the inner value as a dynamic Any reference.

pub fn as_any_mut(&mut self) -> Option<&mut dyn Any>

Get the inner value as a dynamic Any reference.

Source

impl<R: ?Sized> Reader<R>

pub fn as_file_ext(&self) -> Option<&dyn FileExt>

Get the inner value as a dynamic FileExt reference.

pub fn as_fd(&self) -> Option<&dyn AsFd>

Get the inner value as a dynamic AsFd reference.

pub fn as_raw_fd(&self) -> Option<&dyn AsRawFd>

Get the inner value as a dynamic AsRawFd reference.